Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Cloud9.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for AWS Cloud9 - AWS Identity and Access Management

# Actions, Resources, and Condition Keys for AWS Cloud9

AWS Cloud9 (service prefix: `cloud9` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS Cloud9
- Resource Types Defined by AWS Cloud9
- Condition Keys for AWS Cloud9

## Actions Defined by AWS Cloud9

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateEnvironmentEC2 | Grants permission to create an AWS Cloud9 development environment, launches an Amazon Elastic Compute Cloud (Amazon EC2) instance, and then hosts the environment on the instance. | Write |  | cloud9:EnvironmentName cloud9:InstanceType cloud9:SubnetId cloud9:UserArn | ec2:DescribeSubnets ec2:DescribeVpcs iam:CreateServiceLinkedRole
CreateEnvironmentMembership | Grants permission to add an environment member to an AWS Cloud9 development environment. | Write | environment* |  |
| cloud9:UserArn cloud9:EnvironmentId cloud9:Permissions |
DeleteEnvironment | Grants permission to delete an AWS Cloud9 development environment. If the environment is hosted on an Amazon Elastic Compute Cloud (Amazon EC2) instance, also terminates the instance. | Write | environment* |  | iam:CreateServiceLinkedRole
DeleteEnvironmentMembership | Grants permission to delete an environment member from an AWS Cloud9 development environment. | Write | environment* |  |
DescribeEnvironmentMemberships | Grants permission to get information about environment members for an AWS Cloud9 development environment. | Read | environment* |  |
| cloud9:UserArn cloud9:EnvironmentId |
DescribeEnvironmentStatus | Grants permission to get status information for an AWS Cloud9 development environment. | Read | environment* |  |
DescribeEnvironments | Grants permission to get information about AWS Cloud9 development environments. | Read | environment* |  |
GetUserSettings [permission only] | Grants permission to get IDE-specific settings of an AWS Cloud9 user. | Read |  |  |
ListEnvironments | Grants permission to get a list of AWS Cloud9 development environment identifiers. | Read |  |  |
ListTagsForResource | Lists tags for a cloud9 environment | Read | environment* |  |
TagResource | Adds tags to a cloud9 environment | Write | environment* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Removes tags from a cloud9 environment | Write | environment* |  |
| aws:TagKeys |
UpdateEnvironment | Grants permission to change the settings of an existing AWS Cloud9 development environment. | Write | environment* |  |
UpdateEnvironmentMembership | Grants permission to change the settings of an existing environment member for an AWS Cloud9 development environment. | Write | environment* |  |
| cloud9:UserArn cloud9:EnvironmentId cloud9:Permissions |
UpdateUserSettings [permission only] | Grants permission to update IDE-specific settings of an AWS Cloud9 user. | Write |  |  |

## Resource Types Defined by AWS Cloud9

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
environment | `arn:$ { Partition}:cloud9:$ { Region}:$ { Account}:environment:$ { ResourceId}` | aws:ResourceTag/${TagKey}

## Condition Keys for AWS Cloud9

AWS Cloud9 defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | String
cloud9:EnvironmentId | Filters access by the AWS Cloud9 environment ID | String
cloud9:EnvironmentName | Filters access by the AWS Cloud9 environment name | String
cloud9:InstanceType | Filters access by the instance type of the AWS Cloud9 environment's Amazon EC2 instance | String
cloud9:Permissions | Filters access by the type of AWS Cloud9 permissions | String
cloud9:SubnetId | Filters access by the subnet ID that the AWS Cloud9 environment will be created in | String
cloud9:UserArn | Filters access by the user ARN specified | ARN

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.